package com.dcsoft.system.consume.controller;

import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.dcsoft.system.consume.domain.ConsumePeopleDay;
import com.dcsoft.system.consume.service.IConsumePeopleDayService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.dcsoft.common.log.annotation.Log;
import com.dcsoft.common.log.enums.BusinessType;
import com.dcsoft.common.security.annotation.RequiresPermissions;

import com.dcsoft.common.core.web.controller.BaseController;
import com.dcsoft.common.core.web.domain.AjaxResult;
import com.dcsoft.common.core.utils.poi.ExcelUtil;
import com.dcsoft.common.core.web.page.TableDataInfo;

/**
 * 人员餐补信息Controller
 *
 * @author dcsoft
 * @date 2024-09-20
 */
@RestController
@RequestMapping("/consumePeopleDay")
public class ConsumePeopleDayController extends BaseController
{
    @Autowired
    private IConsumePeopleDayService consumePeopleDayService;

    /**
     * 查询人员餐补信息列表
     */
    @RequiresPermissions("consume:consumePeopleDay:list")
    @GetMapping("/list")
    public TableDataInfo list(ConsumePeopleDay consumePeopleDay)
    {
        startPage();
        List<ConsumePeopleDay> list = consumePeopleDayService.selectConsumePeopleDayList(consumePeopleDay);
        return getDataTable(list);
    }

    /**
     * 导出人员餐补信息列表
     */
    @RequiresPermissions("consume:consumePeopleDay:export")
    @Log(title = "人员餐补信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ConsumePeopleDay consumePeopleDay)
    {
        List<ConsumePeopleDay> list = consumePeopleDayService.selectConsumePeopleDayList(consumePeopleDay);
        ExcelUtil<ConsumePeopleDay> util = new ExcelUtil<ConsumePeopleDay>(ConsumePeopleDay.class);
        util.exportExcel(response, list, "人员餐补信息数据");
    }

    /**
     * 获取人员餐补信息详细信息
     */
    @RequiresPermissions("consume:consumePeopleDay:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(consumePeopleDayService.selectConsumePeopleDayById(id));
    }

    /**
     * 新增人员餐补信息
     */
    @RequiresPermissions("consume:consumePeopleDay:add")
    @Log(title = "人员餐补信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ConsumePeopleDay consumePeopleDay)
    {
        return toAjax(consumePeopleDayService.insertConsumePeopleDay(consumePeopleDay));
    }

    /**
     * 修改人员餐补信息
     */
    @RequiresPermissions("consume:consumePeopleDay:edit")
    @Log(title = "人员餐补信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ConsumePeopleDay consumePeopleDay)
    {
        return toAjax(consumePeopleDayService.updateConsumePeopleDay(consumePeopleDay));
    }

    /**
     * 删除人员餐补信息
     */
    @RequiresPermissions("consume:consumePeopleDay:remove")
    @Log(title = "人员餐补信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(consumePeopleDayService.deleteConsumePeopleDayByIds(ids));
    }

    @PostMapping("/syncHkRecord")
    public AjaxResult syncHkRecord(HttpServletResponse response)
    {
        ConsumePeopleDay consumePeopleDay =new ConsumePeopleDay();
        consumePeopleDay.setConsumeTime(new Date());
        return toAjax(consumePeopleDayService.syncHkRecord(consumePeopleDay));
    }

}
